@@ -15,7 +15,7 @@ use DBI;
 
 use vars qw($VERSION);
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use constant {
     DATA => 2,
@@ -263,7 +263,7 @@ sub path_to_root {
     my $res = $self->_selectall_arrayref( "SELECT obj_id,field FROM field WHERE ref_id=?", $obj_id );
     for my $row (@$res) {
 	my( $new_obj_id, $field ) = @$row;
-	if( $self->has_path_to_root( $new_obj_id ) ) {
+	if( $self->has_path_to_root( $new_obj_id, { $obj_id => 1 } ) ) {
 	    return $self->path_to_root( $new_obj_id ) . "/$field";
 	}
     }
